# Calculations
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/calculations#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/calculations#benefits)
  * [Scope](https://help.sap.com/docs/leanix/ea/calculations#scope)
  * [Limitations](https://help.sap.com/docs/leanix/ea/calculations#limitations)
  * [Technical Details](https://help.sap.com/docs/leanix/ea/calculations#technical-details)
  * [Supported Attributes](https://help.sap.com/docs/leanix/ea/calculations#supported-attributes)
  * [Unsupported Attributes](https://help.sap.com/docs/leanix/ea/calculations#unsupported-attributes)
  * [Calculation Templates](https://help.sap.com/docs/leanix/ea/calculations#calculation-templates)


View all
Calculations let you populate fact sheet fields based on values from other fields. Use calculation templates for common scenarios or configure your own to define custom logic.
